.. Gordo Documentation

Welcome to Gordo' documentation!
===========================================

Gordo is a collection of tools to create a distributed
ML service represented by a specific pipeline. Generally, any
:class:`sklearn.pipeline.Pipeline` object can be defined within a config file
and deployed as a REST API service on Kubernetes.

.. toctree::
    :maxdepth: 2

    ./overview.rst
    ./general/index.rst
    ./ml/index.rst
    ./api/index.rst
